@@ -2002,6 +2002,9 @@ EvdevInitProperty(DeviceIntPtr dev)
                     int group = (button % 0x100)/16;
                     int idx = button - ((button/16) * 16);
 
+                    if (!btn_labels[group][idx])
+                        continue;
+
                     atom = XIGetKnownProperty(btn_labels[group][idx]);
                     if (!atom)
                         continue;
@@ -2014,7 +2017,7 @@ EvdevInitProperty(DeviceIntPtr dev)
 
             /* wheel buttons, hardcoded anyway */
             atoms[3] = XIGetKnownProperty(BTN_LABEL_PROP_BTN_WHEEL_UP);
-            atoms[4] = XIGetKnownProperty(BTN_LABEL_PROP_BTN_WHEEL_UP);
+            atoms[4] = XIGetKnownProperty(BTN_LABEL_PROP_BTN_WHEEL_DOWN);
             atoms[5] = XIGetKnownProperty(BTN_LABEL_PROP_BTN_HWHEEL_LEFT);
             atoms[6] = XIGetKnownProperty(BTN_LABEL_PROP_BTN_HWHEEL_RIGHT);
 
